:mod:`lck.django.common.forms`
==============================

.. automodule:: lck.django.common.forms

Classes
--------

.. autoclass:: MassMailingForm
   :show-inheritance:
   :members:
   

.. autoclass:: PolishSelectDateWidget
   :show-inheritance:
   :members:
   

.. autoclass:: Select
   :show-inheritance:
   :members:
   

.. autoclass:: SelectDateWidget
   :show-inheritance:
   :members:
